@@ -13,3 +13,7 @@
 #include "effect_source.h"
 
 
+Effect_Source::~Effect_Source() {
+
+
+}
